@@ -4,6 +4,7 @@
 #' @param tibble_graph A \code{tbl_graph} output by \code{\link[akc]{keyword_group}}.
 #' @param facet Whether the figure should use facet or not.
 #' @param max_nodes The maximum number of nodes displayed in each group.
+#' @param alpha The transparency of label. Must lie between 0 and 1. Default uses 0.7.
 #' @return An object yielded by \code{\link[ggraph]{ggraph}}
 #' @details When \code{facet == TRUE},the function returns a faceted figure with limited number of nodes
 #' (adjuseted by \code{max_nodes} parameter).When \code{facet == FALSE},all the nodes would be displayed in one
@@ -39,7 +40,7 @@
 
 
 
-keyword_vis = function(tibble_graph,facet = TRUE,max_nodes = 10){
+keyword_vis = function(tibble_graph,facet = TRUE,max_nodes = 10,alpha = 0.7){
 
   if(!is.tbl_graph(tibble_graph)) stop("keyword_vis only receives class 'tbl_graph'.")
 
@@ -53,7 +54,7 @@ keyword_vis = function(tibble_graph,facet = TRUE,max_nodes = 10){
       ggraph("kk") +
       geom_edge_link(aes(alpha = n),show.legend = FALSE) +
       geom_node_point(aes(size = freq),show.legend = FALSE) +
-      geom_node_label(aes(label = name,fill = Group),repel = TRUE) +
+      geom_node_label(aes(label = name,fill = Group),repel = TRUE,alpha = alpha) +
       guides(fill = FALSE) +
       theme_no_axes()
   }else{
@@ -66,7 +67,7 @@ keyword_vis = function(tibble_graph,facet = TRUE,max_nodes = 10){
       ggraph("kk") +
       geom_edge_link(aes(alpha = n),show.legend = FALSE) +
       geom_node_point(aes(size = freq),show.legend = FALSE) +
-      geom_node_label(aes(label = name,fill = Group),repel = TRUE) +
+      geom_node_label(aes(label = name,fill = Group),repel = TRUE,alpha = alpha) +
       guides(fill = FALSE) +
       facet_nodes(~Group) +
       theme_no_axes()
